//-----------------------------------------------------------------------------
//    Package Definition
//-----------------------------------------------------------------------------
package uicc.usim.test.usatframework.ufw_exh_genb;

//-----------------------------------------------------------------------------
//  Imports
//-----------------------------------------------------------------------------
import org.etsi.scp.wg3.uicc.jcapi.userinterface.*;
import org.etsi.scp.wg3.uicc.jcapi.userclass.*;
import org._3gpp.ct.wg6.usim.jcapi.userclass.*;
import org._3gpp.ct.wg6.usim.jcapi.userinterface.*;

public class Test_Ufw_Exh_Genb extends UiccTestModel {

    static final String CAP_FILE_PATH = "uicc/usim/test/usatframework/ufw_exh_genb";
    static final String CLASS_AID_1 = "A0000000 871005FF FFFFFF89 50010001";
    static final String APPLET_AID_1 = "A0000000 871005FF FFFFFF89 50010102";
    
    static final String CLASS_AID_2 = "A0000000 871005FF FFFFFF89 50020001";
    static final String APPLET_AID_2 = "A0000000 871005FF FFFFFF89 50020102";
 
       
    private USimAPITestCardService test;
    APDUResponse response;
      
          
    public Test_Ufw_Exh_Genb() {
        test = USimAPITestCardService.getTheUSimTestCardService();
    }
    
    public boolean run() {
        initialiseResults();
        
        // test script
        test.reset();
        test.terminalProfileSession("1719");
    

        // Install package
        test.loadPackage(CAP_FILE_PATH);
            
        // Install Applet1
        test.installApplet(CAP_FILE_PATH, CLASS_AID_1, APPLET_AID_1, 
                           "8008" + // TLV UICC Toolkit application specific parameters
                               "01" +   // V Priority Level
                               "00" +   // V Max. number of timers
                               "00" +   // V Maximum text length for a menu entry
                               "00" +   // V Maximum number of menu entries                              
                               "00" +   // V Maximum number of channels 
                               "00" +   // LV Minimum Security Level field
                               "00" +   // LV TAR Value(s) 
                               "00" );  // V Maximum number of services
        
        // Install Applet2
        test.installApplet(CAP_FILE_PATH, CLASS_AID_2, APPLET_AID_2, 
                           "8008" + // TLV UICC Toolkit application specific parameters
                               "01" +   // V Priority Level
                               "00" +   // V Max. number of timers
                               "00" +   // V Maximum text length for a menu entry
                               "00" +   // V Maximum number of menu entries                              
                               "00" +   // V Maximum number of channels 
                               "00" +   // LV Minimum Security Level field
                               "00" +   // LV TAR Value(s) 
                               "00" );  // V Maximum number of services
          


        
        /*********************************************************************/
        /** Testcase 1. ISOException REPLY_BUSY is not sent to the terminal  */
        /** in multi triggering                                              */
        /*********************************************************************/      
        // 1- Send envelope Event Unformatted SMS PP ENV (multi triggering event, multi registered applets)
        // Applet1 throws ISOException with the reason code REPLY_BUSY 
        response = test.envelopeSmsPp("8B110008 81556677 887FF600 11291200" + 
                                      "000400");
        addResult(response.checkSw("9000"));
        
        
        // 4- Send envelope Event Unformatted SMS PP ENV (multi triggering event, multi registered applets)
        // Applet2 throws ISOException with the reason code REPLY_BUSY 
        response = test.envelopeSmsPp("8B110008 81556677 887FF600 11291200" + 
                                      "000400");
        addResult(response.checkSw("9000"));
        
        
        /*********************************************************************/
        /** Testcase 2. ISOException REPLY_BUSY is sent to the terminal      */
        /** in single triggering                                              */
        /*********************************************************************/      
        // 1- Send envelope Event Formatted SMS PP ENV to trigger Applet1 (single triggering event)
        // Applet1 throws ISOException with the reason code REPLY_BUSY 
        response = test.envelopeSmsPp("0B254008 81556677 887FF600 11291200" +
                                      "00041402 7000000F 0D080000 00500101" +
                                      "00000000 010000"); 
        addResult(response.checkSw("9300"));
        
        
        // 2- Send envelope Event Unformatted SMS CB (multi triggering event, single registered applet)         
        // Applet2 throws ISOException with the reason code REPLY_BUSY 
        response = test.envelopeCellBroadcast("0C58C011 1000F611 00000000 00000000" +
                                              "00000000 00000000 00000000 00000000" +
                                              "00000000 00000000 00000000 00000000" +
                                              "00000000 00000000 00000000 00000000" +
                                              "00000000 00000000 00000000 00000000" +
                                              "00000000 00000000 0000");            
        addResult(response.checkSw("9300"));
                                 
        
        /*********************************************************************/
        /** Testcase 3. Other exception than ISOException REPLY_BUSY         */
        /** are not sent to the terminal                                     */
        /*********************************************************************/      
        // 1- Send envelope Event Formatted SMS PP ENV to trigger Applet1 (single triggering event)
        // Applet1 throws ISOException with the reason code differen to REPLY_BUSY 
        response = test.envelopeSmsPp("0B254008 81556677 887FF600 11291200" +
                                      "00041402 7000000F 0D080000 00500101" +
                                      "00000000 010000"); 
        addResult(response.checkSw("9000"));
        
        // 2- Send envelope Event Formatted SMS PP ENV to trigger Applet1 (single triggering event)
        // Applet1 throws ToolkitException
        response = test.envelopeSmsPp("0B254008 81556677 887FF600 11291200" +
                                      "00041402 7000000F 0D080000 00500101" +
                                      "00000000 010000"); 
        addResult(response.checkSw("9000"));
         
        
               
        /***********************************/        
        /**         Check results          */        
        /***********************************/         
        
        // Select applet1
        response = test.selectApplication(APPLET_AID_1);
        addResult(response.checkData("10" + APPLET_AID_1 +
                                     "05CCCCCC CCCC"));
        // Select applet2
        response = test.selectApplication(APPLET_AID_2);
        addResult(response.checkData("10" + APPLET_AID_2 +
                                     "03CCCCCC"));
    
      
        test.reset();
        test.terminalProfileSession("1719");                                   
        // Delete Applet1 
        test.deleteApplet(APPLET_AID_1);
        // Delete Applet2
        test.deleteApplet(APPLET_AID_2);
        // Delete Package
        test.deletePackage(CAP_FILE_PATH);   
        
        return getOverallResult();
    }
}   
